==> haskell-one-liner-2.1-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1
visibility:           public
id:                   one-liner-2.1-2Dber11ol82KJl7aBdpqkh
key:                  one-liner-2.1-2Dber11ol82KJl7aBdpqkh
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  ea2e0a14e5ad5797e4bd99c369e289e5
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1-2Dber11ol82KJl7aBdpqkh
depends:
    base-4.17.2.1 bifunctors-5.6.2-IxntaptJGqQ3qHgeyi9LXe
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    linear-base-0.5.0-E3Y3zxxiBzBMGmrdjkVc6
    profunctors-5.6.3-7TRwcGddoPPIDmu5JRrCKe
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-one-liner-2.1-244-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-one-liner.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 one-liner
version:              2.1
visibility:           public
id:                   one-liner-2.1-AEJKbae5jvfE8AexPSKllu
key:                  one-liner-2.1-AEJKbae5jvfE8AexPSKllu
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher, Xia Li-yao
homepage:             https://github.com/sjoerdvisscher/one-liner
synopsis:             Constraint-based generics
description:
    Write short and concise generic instances of type classes.
    one-liner is particularly useful for writing default
    implementations of type class methods.

category:             Generics
abi:                  4f62642ac6837230fe75e1df852e8be3
exposed:              True
exposed-modules:
    Generics.OneLiner Generics.OneLiner.Binary
    Generics.OneLiner.Classes Generics.OneLiner.Internal
    Generics.OneLiner.Internal.Unary

import-dirs:          /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/one-liner-2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-one-liner
hs-libraries:         HSone-liner-2.1-AEJKbae5jvfE8AexPSKllu
depends:
    base-4.17.2.1 bifunctors-5.6.2-9ROmtfvKnEA8JCoSpEI25e
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi ghc-prim-0.9.1
    linear-base-0.5.0-AKRwbKO2hWJ6GiO00RNjfJ
    profunctors-5.6.3-B1puex7pinj8XdCtxpi2Qf
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-one-liner/html/one-liner.haddock
haddock-html:         /usr/share/doc/haskell-one-liner/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
